/*
  Esborra les dades de la BD per crear un nou esquema.
 */
DROP DATABASE if EXISTS scart1;

/*
    Creem la base de dades si no existeix
*/
CREATE DATABASE IF NOT EXISTS scart1;

/*
    Obrim la Base de dades la base de dades
*/
USE scart1;

/* ---------- Definicio de les taules ----------- */

/*
	Taula : adminuser

 Taula que conte la informacio de l'administrador :

	* identificador de l'usuari administrador (adreca email de l'organitzacio)
	* password de l'usuari administrador

 La utilitzem al login per validar l'usuari administrador.
 Poden existir molts usuaris administradors, minim n'existira un.

 */

CREATE TABLE IF NOT EXISTS adminuser (

	adminid			INT(11)	NOT NULL AUTO_INCREMENT,
	admincode		VARCHAR(40) NOT NULL DEFAULT '', # email de l_admin dins l_organitzacio
	password		VARCHAR(40) NOT NULL DEFAULT '',

	CONSTRAINT PRIMARY KEY (adminid),
	CONSTRAINT UNIQUE KEY (adminid)

) ENGINE=INNODB;




/*
	Taula : user

	Taula que conte la informacio de l'usuari registrat del portal
	La utilitzarem per enviar-li informacio de les noves publicacions del portal

	usercode es el email de l'usuari

 */

CREATE TABLE IF NOT EXISTS user (

	userid			INT(11) NOT NULL AUTO_INCREMENT,
	usercode		VARCHAR(40) NOT NULL DEFAULT '',  # email de l_usuari
	password		VARCHAR(40) NOT NULL DEFAULT '',
	firstname		VARCHAR(40) NOT NULL DEFAULT '',
	lastname		VARCHAR(40) NOT NULL DEFAULT '',
	address			VARCHAR(40) NOT NULL DEFAULT '',
	city			VARCHAR(40) NOT NULL DEFAULT '',
	zip			VARCHAR(40) NOT NULL DEFAULT '',
	province		VARCHAR(40) NOT NULL DEFAULT '',
	phone			VARCHAR(40) NOT NULL DEFAULT '',
	fax			VARCHAR(40) NOT NULL DEFAULT '',
	mobile			VARCHAR(40) NOT NULL DEFAULT '',
	customerid		INT(11) NOT NULL DEFAULT 0,  # id de client si l'usuari ho es, 0 si no ho es

	CONSTRAINT PRIMARY KEY (userid),
	CONSTRAINT UNIQUE KEY (userid)
) ENGINE=INNODB;




/*
	Taula : customer

	Taula que conte la informacio bancaria del Client (l'usuari comprador)
	Referencia l_usuari al que ja considerem client

 */

CREATE TABLE IF NOT EXISTS customer (

	custid			INT(11) NOT NULL AUTO_INCREMENT,
	numberiduser		INT(11) NOT NULL DEFAULT 0,   # clau a les dades de l_usuari
	cardname		VARCHAR(40) NOT NULL DEFAULT '',
	cardcode		VARCHAR(40) NOT NULL DEFAULT '',
	carcode2		VARCHAR(40) NOT NULL DEFAULT '',
	carcode3		VARCHAR(40) NOT NULL DEFAULT '',
	notes			VARCHAR(40) NOT NULL DEFAULT '',

	CONSTRAINT PRIMARY KEY (custid),
	CONSTRAINT UNIQUE KEY (custid),
	CONSTRAINT fk_user FOREIGN KEY (numberiduser) REFERENCES user(userid) ON DELETE NO ACTION

) ENGINE=INNODB;




/*
	Taula : publication

	Taula que conte la informacio d'una publicacio.
	Les publicacions son items de venda.
 */

CREATE TABLE IF NOT EXISTS publication (

	pubid			INT(11) NOT NULL AUTO_INCREMENT,
	title			VARCHAR(50) NOT NULL DEFAULT '',
	author			VARCHAR(50) NOT NULL DEFAULT '',
	date			DATE NOT NULL DEFAULT 0,
	edition			VARCHAR(10) NOT NULL DEFAULT '',
	revision		VARCHAR(10) NOT NULL DEFAULT '',
	format			VARCHAR(10) NOT NULL DEFAULT '',
	ISBN1			VARCHAR(20) NOT NULL DEFAULT '',
	ISBN2			VARCHAR(20) NOT NULL DEFAULT '',
	ISBN3			VARCHAR(20) NOT NULL DEFAULT '',
	nameimage		VARCHAR(40) NOT NULL DEFAULT '',
	notes			VARCHAR(50) NOT NULL DEFAULT '',
	collectcode		INT(11) NOT NULL DEFAULT 0,
	pubprice		DECIMAL(9, 2) NOT NULL DEFAULT 0,

	CONSTRAINT PRIMARY KEY (pubid),
	CONSTRAINT UNIQUE KEY (pubid)

) ENGINE=INNODB;




/*
	Taula : collection

	Taula que conte les dades d'una col.leccio.
	Les col.leccions son items de venda.
 */

CREATE TABLE IF NOT EXISTS collection (

	colid			INT(11) NOT NULL AUTO_INCREMENT,
	coltitle		VARCHAR(50) NOT NULL DEFAULT '',
	date			DATE NOT NULL  DEFAULT 0,
	format			VARCHAR(10) NOT NULL DEFAULT '',
	ISBN1			VARCHAR(20) NOT NULL DEFAULT '',
	ISBN2			VARCHAR(20) NOT NULL DEFAULT '',
	ISBN3			VARCHAR(20) NOT NULL DEFAULT '',
	nameimage		VARCHAR(40) NOT NULL DEFAULT '',
	notes			VARCHAR(50) NOT NULL DEFAULT '',
	colprice		DECIMAL(9, 2) NOT NULL DEFAULT 0.0,
	pubstotal		DECIMAL(9, 2) NOT NULL DEFAULT 0.0,

	CONSTRAINT PRIMARY KEY (colid),
	CONSTRAINT UNIQUE KEY (colid)

) ENGINE=INNODB;




/*
	Taula : collectitems

	Taula que conte les dades d'una col.leccio.
	Les col.leccions son items de venda.
 */

CREATE TABLE IF NOT EXISTS collectitem (

	seqid			INT(11) NOT NULL AUTO_INCREMENT,

	colitid			INT(11) NOT NULL DEFAULT 0,
	colitindex		INT(11) NOT NULL DEFAULT 0,

	colitpubid		INT(11) NOT NULL DEFAULT 0,

	CONSTRAINT PRIMARY KEY (seqid),
	CONSTRAINT UNIQUE KEY  (seqid),
	CONSTRAINT fk_cicollection FOREIGN KEY (colitid) REFERENCES collection(colid) ON DELETE NO ACTION,
	CONSTRAINT fk_cipublication FOREIGN KEY (colitpubid) REFERENCES publication(pubid) ON DELETE NO ACTION

) ENGINE=INNODB;




/*
	Taula : teme

	Taula que assigna a les publicacions un tema o mes d'un.
 */

CREATE TABLE IF NOT EXISTS teme (

	id				INT(11) NOT NULL AUTO_INCREMENT,
	code			VARCHAR(20) NOT NULL DEFAULT '',  # Codi del tema; exemple : ANDR
	description		VARCHAR(40) NOT NULL DEFAULT '',  # Descripcio del tema      Android

	CONSTRAINT PRIMARY KEY (id),
	CONSTRAINT UNIQUE KEY (id)

) ENGINE=INNODB;




/*
	Taula : publiteme

	Taula que assigna a les publicacions un tema o mes d'un.
 */

CREATE TABLE IF NOT EXISTS publiteme (

	id		INT(11) NOT NULL AUTO_INCREMENT,
	pubid	INT(11) NOT NULL DEFAULT 0,
	temeid	INT(11) NOT NULL DEFAULT 0,

	CONSTRAINT PRIMARY KEY (id),
	CONSTRAINT UNIQUE KEY (id),
	CONSTRAINT fk_pt_publication FOREIGN KEY (pubid) REFERENCES publication(pubid) ON DELETE NO ACTION,
	CONSTRAINT fk_pt_teme FOREIGN KEY (temeid) REFERENCES teme(id) ON DELETE NO ACTION

) ENGINE=INNODB;




/*
	Taula : orders

	Taula que desa les dades generals de la comanda del cistell de compra.
 */

CREATE TABLE IF NOT EXISTS orders (

	orderid			INT(11) NOT NULL AUTO_INCREMENT,

	orderyear		INT(04) NOT NULL DEFAULT 0,
	ordernumber		INT(11) NOT NULL DEFAULT 0,
	orderdate		DATE NOT NULL DEFAULT 0,

	ordercustid		INT(11) NOT NULL DEFAULT 0,

	CONSTRAINT PRIMARY KEY  (orderid),
	CONSTRAINT UNIQUE KEY (orderid),
	CONSTRAINT fk_customer FOREIGN KEY (ordercustid) REFERENCES customer(custid) ON DELETE NO ACTION

) ENGINE=INNODB;




/*
	Taula : orderitems

	Taula que desa les linies de la comanda del cistell de compra.
 */

CREATE TABLE IF NOT EXISTS orderitems (

	seqid			INT(11) AUTO_INCREMENT,

	orderi_orderid	INT(11) NOT NULL DEFAULT 0,
	orderi_line		INT(11) NOT NULL DEFAULT 0,

	prodorcol		INT(5) NOT NULL DEFAULT '0', # publicacio = 1;  col.leccio = 2.
	itemid			INT(11) NOT NULL DEFAULT '0', # id de la publicacio o de la col.leccio.
	name			VARCHAR(20) NOT NULL DEFAULT '', # Descripció del producte
	quantity		INT(11) NOT NULL DEFAULT 0,
	price			DECIMAL(9, 2) NOT NULL DEFAULT 0,
	discount		DECIMAL(3, 2) NOT NULL DEFAULT 0,

	CONSTRAINT PRIMARY KEY  (seqid),
	CONSTRAINT UNIQUE KEY (seqid),
	CONSTRAINT fk_order FOREIGN KEY (orderi_orderid) REFERENCES orders(orderid) ON DELETE NO ACTION

) ENGINE=INNODB;



